@@ -14,12 +14,13 @@
 #include <QtCore/QStringList>
 #include <Snapd/WrappedObject>
 
-class Q_DECL_EXPORT QSnapdChangeData : public QSnapdWrappedObject
-{
-    Q_OBJECT
+#include "snapdqt_global.h"
+
+class LIBSNAPDQT_EXPORT QSnapdChangeData : public QSnapdWrappedObject {
+  Q_OBJECT
 
 public:
-    explicit QSnapdChangeData (void* snapd_object, QObject* parent = 0);
+  explicit QSnapdChangeData(void *snapd_object, QObject *parent = 0);
 };
 
 #endif
